@@ -1,7 +1,7 @@
 package Module::Patch;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -118,6 +118,10 @@ sub import {
             croak "$self: Unknown option(s): ".join(", ", keys %opts);
         }
 
+        if ($pdata->{after_read_config}) {
+            $pdata->{after_read_config}->();
+        }
+
         ${"$self\::handles"} = patch_package(
             $target, $pdata->{patches},
             {force=>$force, patch_module=>ref($self) || $self});
@@ -251,7 +255,7 @@ Module::Patch - Patch package with a set of patches
 
 =head1 VERSION
 
-This document describes version 0.22 of Module::Patch (from Perl distribution Module-Patch), released on 2015-08-17.
+This document describes version 0.23 of Module::Patch (from Perl distribution Module-Patch), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -349,6 +353,33 @@ patching.
 
 =for Pod::Coverage ^(unimport|patch_data)$
 
+=head1 PATCH DATA SPECIFICATION
+
+Patch data must be stored in C<patch_data()> subroutine. It must be a L<DefHash>
+(i.e. a regular Perl hash) with the following known properties:
+
+=over
+
+=item * v => int
+
+Must be 3 (current version).
+
+=item * patches => array
+
+Will be passed to L<Monkey::Patch::Action>'s C<patch_package()>.
+
+=item * config => hash
+
+A hash of name and config specifications. Config specification is another
+DefHash and can contain the following properties: C<schema> (a L<Sah> schema),
+C<default> (default value).
+
+=item * after_read_config => coderef
+
+A hook to run after patch module is imported and configuration has been read.
+
+=back
+
 =head1 FUNCTIONS
 
 =head2 import()
@@ -450,19 +481,6 @@ C<-warn_target_loaded> is set to false).
 
 =back
 
-=head1 SEE ALSO
-
-L<Monkey::Patch::Action>
-
-L<Pod::Weaver::Plugin::ModulePatch>
-
-Some examples of patch modules that use Module::Patch by subclassing it:
-L<Net::HTTP::Methods::Patch::LogRequest>,
-L<LWP::UserAgent::Patch::HTTPSHardTimeout>.
-
-Some examples of modules that use Module::Patch directly:
-L<Log::Any::For::Class>.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Module-Patch>.
@@ -479,13 +497,26 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Monkey::Patch::Action>
+
+L<Pod::Weaver::Plugin::ModulePatch>
+
+Some examples of patch modules that use Module::Patch by subclassing it:
+L<Net::HTTP::Methods::Patch::LogRequest>,
+L<LWP::UserAgent::Patch::HTTPSHardTimeout>.
+
+Some examples of modules that use Module::Patch directly:
+L<Log::Any::For::Class>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
